#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>

#include "../vipipc.h"
#include "../vipipc_prototypes.h"

void usage(const char* myname) {
	fprintf(stderr, "usage: %s <command>\n"
			"commands:\n"
			"\tget\n"
			"\t\toutputs current volume setting\n"
			"\tset V\n"
			"\t\tsets volume level to V (0-100)\n", myname);
	exit(1);
}

int main(int argc, char* argv[]) {
	int err, volume;
	ipcconn ns, vs;

	/* we are (most probably) not run by appman */

	if(argc < 2) usage(argv[0]);

	ns = ipcconn_get_nameservice();
	if(!ns) {
		fprintf(stderr, "error creating nameservice ipcconn\n");
		exit(1);
	}

	vs = VolumeService_new(ns);
	if(!vs) {
		fprintf(stderr, "error creating volumeservice ipcconn\n");
		ipcconn_free(&ns);
		exit(2);
	}

	if(!strcmp("get", argv[1])) {
		err = VolumeService_GetVolume(vs, &volume);
		if(err)
			fprintf(stderr, "error %d when trying to get volume.\n", err);
		else
			printf("%d\n", volume);
	} else if(!strcmp("set", argv[1])) {
		if(argc < 3) usage(argv[0]);
		volume = atoi(argv[2]);
		err = VolumeService_SetVolume(vs, volume);
		if(err)
			fprintf(stderr, "error %d when trying to set volume.\n", err);
	}

	ipcconn_free(&vs);
	ipcconn_free(&ns);
	exit(err);
}

